Module com.webfirmframework.wffweb
Class AnimationIterationCount
java.lang.Object
com.webfirmframework.wffweb.css.core.AbstractCssProperty<AnimationIterationCount>
com.webfirmframework.wffweb.css.css3.AnimationIterationCount
- All Implemented Interfaces:
CssProperty,Serializable,Cloneable
animation-iteration-count: number|initial|inherit; The animation-iteration-count property specifies the number of times an animation should be played. Default value: 1 Inherited: no Animatable: no Version: CSS3 JavaScript syntax: object.style.animationIterationCount="infinite"
- Since:
- 1.0.0
- Author:
- WFF
- See Also:
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionThe default value 1 will be set as the cssValue.AnimationIterationCount(int value) AnimationIterationCount(AnimationIterationCount animationIterationCount) AnimationIterationCount(String cssValue) -
Method Summary
Modifier and TypeMethodDescriptiongetValue()gets the animationIterationCount inIntegervalue.static booleanvalidates if the given cssValue is valid for this class.voidsets asinfinitevoidsets asinheritvoidsets asinitialsetCssValue(String cssValue) voidsetValue(int value) toString()Methods inherited from class com.webfirmframework.wffweb.css.core.AbstractCssProperty
clone, getStateChangeInformer, isAlreadyInUse, setAlreadyInUse, setStateChangeInformer, toCssString
-
Field Details
-
INITIAL
- See Also:
-
INHERIT
- See Also:
-
INFINITE
- See Also:
-
-
Constructor Details
-
AnimationIterationCount
public AnimationIterationCount()The default value 1 will be set as the cssValue.- Since:
- 1.0.0
-
AnimationIterationCount
- Parameters:
cssValue- the css value to set.
-
AnimationIterationCount
- Parameters:
animationIterationCount- theOpacityobject from which the cssValue to set.And,nullwill throwNullValueException
-
AnimationIterationCount
public AnimationIterationCount(int value) - Parameters:
value-
-
-
Method Details
-
getCssName
- Returns:
- the name portion in style, eg
align-contentfor stylealign-content: center.
-
getCssValue
- Returns:
- the value portion in style, eg
centerfor stylealign-content: center.
-
toString
-
getValue
gets the animationIterationCount inIntegervalue.- Returns:
- the value in int or null if the cssValue is
initialorinherit. - Since:
- 1.0.0
-
setValue
public void setValue(int value) - Parameters:
value- the value to set- Since:
- 1.0.0
-
setCssValue
- Specified by:
setCssValuein classAbstractCssProperty<AnimationIterationCount>- Parameters:
cssValue- the value should be in the format of0.5,initial/inherit.nullis considered as an invalid value and it will throwNullValueException.- Returns:
- the current object.
- Since:
- 1.0.0
-
setAsInitial
public void setAsInitial()sets asinitial- Since:
- 1.0.0
-
setAsInherit
public void setAsInherit()sets asinherit- Since:
- 1.0.0
-
setAsInfinite
public void setAsInfinite()sets asinfinite- Since:
- 1.0.0
-
isValid
validates if the given cssValue is valid for this class.- Parameters:
cssValue- the value to check.- Returns:
- true if valid and false if invalid.
- Since:
- 1.0.0
-