Module com.webfirmframework.wffweb
Class MozColumnCount
java.lang.Object
com.webfirmframework.wffweb.css.core.AbstractCssProperty<MozColumnCount>
com.webfirmframework.wffweb.css.css3.MozColumnCount
- All Implemented Interfaces:
CssProperty,Serializable,Cloneable
-moz-column-count: number|auto|initial|inherit; The -moz-column-count property specifies the number of columns an element should be divided into. Default value: auto Inherited: no Animatable: yes Version: CSS3 JavaScript syntax: object.style.mozColumnCount=3
- Since:
- 1.0.0
- Author:
- WFF
- See Also:
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionThe default value 1 will be set as the cssValue.MozColumnCount(int value) MozColumnCount(MozColumnCount mozColumnCount) MozColumnCount(String cssValue) -
Method Summary
Modifier and TypeMethodDescriptiongetValue()gets the mozColumnCount inIntegervalue.static booleanvalidates if the given cssValue is valid for this class.voidsets asautovoidsets asinheritvoidsets asinitialsetCssValue(String cssValue) voidsetValue(int value) toString()Methods inherited from class com.webfirmframework.wffweb.css.core.AbstractCssProperty
clone, getStateChangeInformer, isAlreadyInUse, setAlreadyInUse, setStateChangeInformer, toCssString
-
Field Details
-
INITIAL
- See Also:
-
INHERIT
- See Also:
-
AUTO
- See Also:
-
-
Constructor Details
-
MozColumnCount
public MozColumnCount()The default value 1 will be set as the cssValue.- Since:
- 1.0.0
-
MozColumnCount
- Parameters:
cssValue- the css value to set.
-
MozColumnCount
- Parameters:
mozColumnCount- theOpacityobject from which the cssValue to set.And,nullwill throwNullValueException
-
MozColumnCount
public MozColumnCount(int value) - Parameters:
value-
-
-
Method Details
-
getCssName
- Returns:
- the name portion in style, eg
align-contentfor stylealign-content: center.
-
getCssValue
- Returns:
- the value portion in style, eg
centerfor stylealign-content: center.
-
toString
-
getValue
gets the mozColumnCount inIntegervalue.- Returns:
- the value in int or null if the cssValue is
initialorinherit. - Since:
- 1.0.0
-
setValue
public void setValue(int value) - Parameters:
value- the value to set- Since:
- 1.0.0
-
setCssValue
- Specified by:
setCssValuein classAbstractCssProperty<MozColumnCount>- Parameters:
cssValue- the value should be in the format of0.5,initial/inherit.nullis considered as an invalid value and it will throwNullValueException.- Returns:
- the current object.
- Since:
- 1.0.0
-
setAsInitial
public void setAsInitial()sets asinitial- Since:
- 1.0.0
-
setAsInherit
public void setAsInherit()sets asinherit- Since:
- 1.0.0
-
setAsAuto
public void setAsAuto()sets asauto- Since:
- 1.0.0
-
isValid
validates if the given cssValue is valid for this class.- Parameters:
cssValue- the value to check.- Returns:
- true if valid and false if invalid.
- Since:
- 1.0.0
-