Module com.webfirmframework.wffweb
Class WebkitColumnWidth
java.lang.Object
com.webfirmframework.wffweb.css.core.AbstractCssProperty<WebkitColumnWidth>
com.webfirmframework.wffweb.css.css3.WebkitColumnWidth
- All Implemented Interfaces:
CssProperty,Serializable,Cloneable
This is for Chrome, Safari and Opera.
-webkit-column-width: auto|length|initial|inherit; The -webkit-column-width property specifies the width of the columns. Default value: auto Inherited: no Animatable: yes Version: CSS3 JavaScript syntax: object.style.columnWidth="5px"
- Since:
- 1.0.0
- Author:
- WFF
- See Also:
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionThemediumwill be set as the valueWebkitColumnWidth(float percent) WebkitColumnWidth(float value, CssLengthUnit cssLengthUnit) WebkitColumnWidth(WebkitColumnWidth webkitColumnWidth) WebkitColumnWidth(String cssValue) -
Method Summary
Modifier and TypeMethodDescriptiongetUnit()getValue()gets the -webkit-column-width in float value.voidsets asauto.voidsets asinheritvoidsets asinitialsetCssValue(String cssValue) voidsetPercent(float percent) setValue(float value, CssLengthUnit cssLengthUnit) toString()Methods inherited from class com.webfirmframework.wffweb.css.core.AbstractCssProperty
clone, getStateChangeInformer, isAlreadyInUse, setAlreadyInUse, setStateChangeInformer, toCssString
-
Field Details
-
AUTO
- See Also:
-
INITIAL
- See Also:
-
INHERIT
- See Also:
-
-
Constructor Details
-
WebkitColumnWidth
public WebkitColumnWidth()Themediumwill be set as the value -
WebkitColumnWidth
- Parameters:
cssValue- the css value to set.
-
WebkitColumnWidth
- Parameters:
webkitColumnWidth- theWebkitColumnWidthobject from which the cssValue to set.And,nullwill throwNullValueException
-
WebkitColumnWidth
public WebkitColumnWidth(float percent) - Parameters:
percent- the percentage value to set. The cssLengthUnit will automatically set to %.- Since:
- 1.0.0
-
WebkitColumnWidth
- Parameters:
value-cssLengthUnit-
-
-
Method Details
-
setValue
- Parameters:
value-cssLengthUnit-- Returns:
- the current object
- Since:
- 1.0.0
-
setPercent
public void setPercent(float percent) - Parameters:
percent- the percent to set- Since:
- 1.0.0
-
getCssName
- Returns:
- the name portion in style, eg
align-contentfor stylealign-content: center.
-
getCssValue
- Returns:
- the value portion in style, eg
centerfor stylealign-content: center.
-
toString
-
getValue
gets the -webkit-column-width in float value.WebkitColumnWidth#getUnit()should be used to get the cssLengthUnit for this value.- Returns:
- the value in float or null if the cssValue is
initialorinherit. - Since:
- 1.0.0
-
getUnit
- Returns:
- the cssLengthUnit
PX/PER, ornullif the value is any inbuilt value likeinherit. - Since:
- 1.0.0
-
setCssValue
- Specified by:
setCssValuein classAbstractCssProperty<WebkitColumnWidth>- Parameters:
cssValue- the value should be in the format of55pxor95%.nullis considered as an invalid value and it will throwNullValueException.- Returns:
- the current object.
- Since:
- 1.0.0
-
setAsInitial
public void setAsInitial()sets asinitial- Since:
- 1.0.0
-
setAsInherit
public void setAsInherit()sets asinherit- Since:
- 1.0.0
-
setAsAuto
public void setAsAuto()sets asauto.- Since:
- 1.0.0
-